==> goobox-0.4.0.tar.gz: goobox-0.4.0/src/goo-stock.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Goo
 *
 *  Copyright (C) 2004 Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef GOO_STOCK_H
#define GOO_STOCK_H

#define GOO_STOCK_EJECT       "media-eject"
#define GOO_STOCK_EXTRACT     "gtk-cdrom"
#define GOO_STOCK_NEXT        "media-next"
#define GOO_STOCK_PAUSE       "media-pause"
#define GOO_STOCK_PLAY        "media-play"
#define GOO_STOCK_PREV        "media-prev"
#define GOO_STOCK_RESET       "goo-reset"
#define GOO_STOCK_STOP        "media-stop"
#define GOO_STOCK_NO_COVER    "goo-no-cover"
#define GOO_STOCK_VOLUME_MAX  "volume-max"
#define GOO_STOCK_VOLUME_MED  "volume-med"
#define GOO_STOCK_VOLUME_MIN  "volume-min"
#define GOO_STOCK_VOLUME_ZERO "volume-zero"
#define GOO_STOCK_WEB         "panel-internet"


void goo_stock_init (void);


#endif /* GOO_STOCK_H */

==> goobox-0.9.90.tar.gz: goobox-0.9.90/src/goo-stock.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Goo
 *
 *  Copyright (C) 2004 Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef GOO_STOCK_H
#define GOO_STOCK_H

#define GOO_STOCK_EJECT       "media-eject"
#define GOO_STOCK_EXTRACT     "gtk-cdrom"
#define GOO_STOCK_NEXT        "media-next"
#define GOO_STOCK_PAUSE       "media-pause"
#define GOO_STOCK_PLAY        "media-play"
#define GOO_STOCK_PREV        "media-prev"
#define GOO_STOCK_RESET       "goo-reset"
#define GOO_STOCK_STOP        "media-stop"
#define GOO_STOCK_NO_COVER    "goo-no-cover"
#define GOO_STOCK_VOLUME_MAX  "goo-volume-max"
#define GOO_STOCK_VOLUME_MED  "goo-volume-med"
#define GOO_STOCK_VOLUME_MIN  "goo-volume-min"
#define GOO_STOCK_VOLUME_ZERO "goo-volume-zero"
#define GOO_STOCK_WEB         "panel-internet"


void goo_stock_init (void);


#endif /* GOO_STOCK_H */
